@@ -29,6 +29,24 @@ from kasa.klaptransport import KlapEncryptionSession, KlapTransportV2
 from kasa.protocol import DEFAULT_CREDENTIALS, get_default_credentials
 
 
+def _is_http_response_for_packet(response, packet):
+    """Return True if the *response* contains a response for request in *packet*.
+
+    Different tshark versions use different field for the information.
+    """
+    if not hasattr(response, "http"):
+        return False
+    if hasattr(response.http, "response_for_uri") and (
+        response.http.response_for_uri == packet.http.request_full_uri
+    ):
+        return True
+    # tshark 4.4.0
+    if response.http.request_uri == packet.http.request_uri:
+        return True
+
+    return False
+
+
 class MyEncryptionSession(KlapEncryptionSession):
     """A custom KlapEncryptionSession class that allows for decryption."""
 
@@ -194,6 +212,7 @@ def main(
     username,
     password,
     device_ip,
+    source_host,
     pcap_file_path,
     output_json_name=None,
 ):
@@ -214,7 +233,6 @@ def main(
     )
 
     operator = Operator(KlapTransportV2(config=fake_device), creds)
-
     packets = []
 
     # pyshark is a little weird in how it handles iteration,
@@ -222,7 +240,9 @@ def main(
     while True:
         try:
             packet = capture.next()
-            # packet_number = capture._current_packet
+            packet_number = capture._current_packet
+            if packet.ip.src != source_host:
+                continue
             # we only care about http packets
             if hasattr(
                 packet, "http"
@@ -267,18 +287,16 @@ def main(
                         message = bytes.fromhex(data)
                         operator.local_seed = message
                         response = None
+                        print(
+                            f"got handshake1 in {packet_number}, "
+                            f"looking for the response"
+                        )
                         while (
                             True
                         ):  # we are going to now look for the response to this request
                             response = capture.next()
-                            if (
-                                hasattr(response, "http")
-                                and hasattr(response.http, "response_for_uri")
-                                and (
-                                    response.http.response_for_uri
-                                    == packet.http.request_full_uri
-                                )
-                            ):
+                            if _is_http_response_for_packet(response, packet):
+                                print(f"found response in {packet_number}")
                                 break
                         data = response.http.get_field_value("file_data", raw=True)
                         message = bytes.fromhex(data)
@@ -309,6 +327,11 @@ def main(
     required=True,
     help="the IP of the smart device as it appears in the pcap file.",
 )
+@click.option(
+    "--source-host",
+    required=True,
+    help="the IP of the device communicating with the smart device.",
+)
 @click.option(
     "--username",
     required=True,
@@ -332,14 +355,14 @@ def main(
     required=False,
     help="The name of the output file, relative to the current directory.",
 )
-async def cli(username, password, host, pcap_file_path, output):
+async def cli(username, password, host, source_host, pcap_file_path, output):
     """Export KLAP data in JSON format from a PCAP file."""
     # pyshark does not work within a running event loop and we don't want to
     # install click as well as asyncclick so run in a new thread.
     loop = asyncio.new_event_loop()
     thread = Thread(
         target=main,
-        args=[loop, username, password, host, pcap_file_path, output],
+        args=[loop, username, password, host, source_host, pcap_file_path, output],
         daemon=True,
     )
     thread.start()
