@@ -262,7 +262,7 @@ class _DiscoverProtocol(asyncio.DatagramProtocol):
             self._handle_discovered_event()
             return
         except KasaException as ex:
-            _LOGGER.debug(f"[DISCOVERY] Unable to find device type for {ip}: {ex}")
+            _LOGGER.debug("[DISCOVERY] Unable to find device type for %s: %s", ip, ex)
             self.invalid_device_exceptions[ip] = ex
             self._handle_discovered_event()
             return
@@ -296,8 +296,8 @@ class Discover:
 
     DISCOVERY_PORT = 9999
 
-    DISCOVERY_QUERY = {
-        "system": {"get_sysinfo": None},
+    DISCOVERY_QUERY: dict[str, dict[str, dict]] = {
+        "system": {"get_sysinfo": {}},
     }
 
     DISCOVERY_PORT_2 = 20002
