@@ -10,6 +10,7 @@ from ..device_type import DeviceType
 from ..deviceconfig import DeviceConfig
 from ..smartprotocol import SmartProtocol, _ChildProtocolWrapper
 from .smartdevice import SmartDevice
+from .smartmodule import SmartModule
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -41,13 +42,29 @@ class SmartChildDevice(SmartDevice):
         The parent updates our internal info so just update modules with
         their own queries.
         """
+        await self._update(update_children)
+
+    async def _update(self, update_children: bool = True):
+        """Update child module info.
+
+        Internal implementation to allow patching of public update in the cli
+        or test framework.
+        """
+        now = time.monotonic()
+        module_queries: list[SmartModule] = []
         req: dict[str, Any] = {}
         for module in self.modules.values():
-            if mod_query := module.query():
+            if module.disabled is False and (mod_query := module.query()):
+                module_queries.append(module)
                 req.update(mod_query)
         if req:
             self._last_update = await self.protocol.query(req)
-            self._last_update_time = time.time()
+
+        for module in self.modules.values():
+            await self._handle_module_post_update(
+                module, now, had_query=module in module_queries
+            )
+        self._last_update_time = now
 
     @classmethod
     async def create(cls, parent: SmartDevice, child_info, child_components):
