@@ -5,6 +5,7 @@ import re
 import asyncclick as click
 import pytest
 from asyncclick.testing import CliRunner
+from pytest_mock import MockerFixture
 
 from kasa import (
     AuthenticationError,
@@ -16,28 +17,29 @@ from kasa import (
     Module,
     UnsupportedDeviceError,
 )
-from kasa.cli import (
-    TYPE_TO_CLASS,
+from kasa.cli.device import (
     alias,
-    brightness,
-    cli,
-    cmd_command,
-    effect,
-    emeter,
-    hsv,
+    factory_reset,
     led,
-    raw_command,
     reboot,
     state,
     sysinfo,
-    temperature,
-    time,
     toggle,
     update_credentials,
-    wifi,
 )
+from kasa.cli.light import (
+    brightness,
+    effect,
+    hsv,
+    temperature,
+)
+from kasa.cli.main import TYPES, _legacy_type_to_class, cli, cmd_command, raw_command
+from kasa.cli.time import time
+from kasa.cli.usage import emeter, energy
+from kasa.cli.wifi import wifi
 from kasa.discover import Discover, DiscoveryResult
 from kasa.iot import IotDevice
+from kasa.smart import SmartDevice
 
 from .conftest import (
     device_smart,
@@ -57,12 +59,17 @@ def runner():
     return runner
 
 
+async def test_help(runner):
+    """Test that all the lazy modules are correctly names."""
+    res = await runner.invoke(cli, ["--help"])
+    assert res.exit_code == 0, "--help failed, check lazy module names"
+
+
 @pytest.mark.parametrize(
     ("device_family", "encrypt_type"),
     [
         pytest.param(None, None, id="No connect params"),
         pytest.param("SMART.TAPOPLUG", None, id="Only device_family"),
-        pytest.param(None, "KLAP", id="Only encrypt_type"),
     ],
 )
 async def test_update_called_by_cli(dev, mocker, runner, device_family, encrypt_type):
@@ -171,13 +178,16 @@ async def test_command_with_child(dev, mocker, runner):
     class DummyDevice(dev.__class__):
         def __init__(self):
             super().__init__("127.0.0.1")
+            # device_type and _info initialised for repr
+            self._device_type = Device.Type.StripSocket
+            self._info = {}
 
         async def _query_helper(*_, **__):
             return {"dummy": "response"}
 
     dummy_child = DummyDevice()
 
-    mocker.patch.object(dev, "_children", {"XYZ": dummy_child})
+    mocker.patch.object(dev, "_children", {"XYZ": [dummy_child]})
     mocker.patch.object(dev, "get_child_device", return_value=dummy_child)
 
     res = await runner.invoke(
@@ -206,6 +216,21 @@ async def test_reboot(dev, mocker, runner):
     assert res.exit_code == 0
 
 
+@device_smart
+async def test_factory_reset(dev, mocker, runner):
+    """Test that factory reset works on SMART devices."""
+    query_mock = mocker.patch.object(dev.protocol, "query")
+
+    res = await runner.invoke(
+        factory_reset,
+        obj=dev,
+        input="y\n",
+    )
+
+    query_mock.assert_called()
+    assert res.exit_code == 0
+
+
 @device_smart
 async def test_wifi_scan(dev, runner):
     res = await runner.invoke(wifi, ["scan"], obj=dev)
@@ -314,9 +339,9 @@ async def test_emeter(dev: Device, mocker, runner):
 
     if not dev.is_strip:
         res = await runner.invoke(emeter, ["--index", "0"], obj=dev)
-        assert "Index and name are only for power strips!" in res.output
+        assert f"Device: {dev.host} does not have children" in res.output
         res = await runner.invoke(emeter, ["--name", "mock"], obj=dev)
-        assert "Index and name are only for power strips!" in res.output
+        assert f"Device: {dev.host} does not have children" in res.output
 
     if dev.is_strip and len(dev.children) > 0:
         realtime_emeter = mocker.patch.object(dev.children[0], "get_emeter_realtime")
@@ -496,7 +521,7 @@ async def test_credentials(discovery_mock, mocker, runner):
                 f"Username:{dev.credentials.username} Password:{dev.credentials.password}"
             )
 
-    mocker.patch("kasa.cli.state", new=_state)
+    mocker.patch("kasa.cli.device.state", new=_state)
 
     dr = DiscoveryResult(**discovery_mock.discovery_data["result"])
     res = await runner.invoke(
@@ -731,7 +756,7 @@ async def test_host_auth_failed(discovery_mock, mocker, runner):
     assert isinstance(res.exception, AuthenticationError)
 
 
-@pytest.mark.parametrize("device_type", list(TYPE_TO_CLASS))
+@pytest.mark.parametrize("device_type", TYPES)
 async def test_type_param(device_type, mocker, runner):
     """Test for handling only one of username or password supplied."""
     result_device = FileNotFoundError
@@ -742,8 +767,11 @@ async def test_type_param(device_type, mocker, runner):
         nonlocal result_device
         result_device = dev
 
-    mocker.patch("kasa.cli.state", new=_state)
-    expected_type = TYPE_TO_CLASS[device_type]
+    mocker.patch("kasa.cli.device.state", new=_state)
+    if device_type == "smart":
+        expected_type = SmartDevice
+    else:
+        expected_type = _legacy_type_to_class(device_type)
     mocker.patch.object(expected_type, "update")
     res = await runner.invoke(
         cli,
@@ -930,3 +958,110 @@ async def test_feature_set_child(mocker, runner):
     assert f"Targeting child device {child_id}"
     assert "Changing state from False to True" in res.output
     assert res.exit_code == 0
+
+
+async def test_cli_child_commands(
+    dev: Device, runner: CliRunner, mocker: MockerFixture
+):
+    if not dev.children:
+        res = await runner.invoke(alias, ["--child-index", "0"], obj=dev)
+        assert f"Device: {dev.host} does not have children" in res.output
+        assert res.exit_code == 1
+
+        res = await runner.invoke(alias, ["--index", "0"], obj=dev)
+        assert f"Device: {dev.host} does not have children" in res.output
+        assert res.exit_code == 1
+
+        res = await runner.invoke(alias, ["--child", "Plug 2"], obj=dev)
+        assert f"Device: {dev.host} does not have children" in res.output
+        assert res.exit_code == 1
+
+        res = await runner.invoke(alias, ["--name", "Plug 2"], obj=dev)
+        assert f"Device: {dev.host} does not have children" in res.output
+        assert res.exit_code == 1
+
+    if dev.children:
+        child_alias = dev.children[0].alias
+        assert child_alias
+        child_device_id = dev.children[0].device_id
+        child_count = len(dev.children)
+        child_update_method = dev.children[0].update
+
+        # Test child retrieval
+        res = await runner.invoke(alias, ["--child-index", "0"], obj=dev)
+        assert f"Targeting child device {child_alias}" in res.output
+        assert res.exit_code == 0
+
+        res = await runner.invoke(alias, ["--index", "0"], obj=dev)
+        assert f"Targeting child device {child_alias}" in res.output
+        assert res.exit_code == 0
+
+        res = await runner.invoke(alias, ["--child", child_alias], obj=dev)
+        assert f"Targeting child device {child_alias}" in res.output
+        assert res.exit_code == 0
+
+        res = await runner.invoke(alias, ["--name", child_alias], obj=dev)
+        assert f"Targeting child device {child_alias}" in res.output
+        assert res.exit_code == 0
+
+        res = await runner.invoke(alias, ["--child", child_device_id], obj=dev)
+        assert f"Targeting child device {child_alias}" in res.output
+        assert res.exit_code == 0
+
+        res = await runner.invoke(alias, ["--name", child_device_id], obj=dev)
+        assert f"Targeting child device {child_alias}" in res.output
+        assert res.exit_code == 0
+
+        # Test invalid name and index
+        res = await runner.invoke(alias, ["--child-index", "-1"], obj=dev)
+        assert f"Invalid index -1, device has {child_count} children" in res.output
+        assert res.exit_code == 1
+
+        res = await runner.invoke(alias, ["--child-index", str(child_count)], obj=dev)
+        assert (
+            f"Invalid index {child_count}, device has {child_count} children"
+            in res.output
+        )
+        assert res.exit_code == 1
+
+        res = await runner.invoke(alias, ["--child", "foobar"], obj=dev)
+        assert "No child device found with device_id or name: foobar" in res.output
+        assert res.exit_code == 1
+
+        # Test using both options:
+
+        res = await runner.invoke(
+            alias, ["--child", child_alias, "--child-index", "0"], obj=dev
+        )
+        assert "Use either --child or --child-index, not both." in res.output
+        assert res.exit_code == 2
+
+        # Test child with no parameter interactive prompt
+
+        res = await runner.invoke(alias, ["--child"], obj=dev, input="0\n")
+        assert "Enter the index number of the child device:" in res.output
+        assert f"Alias: {child_alias}" in res.output
+        assert res.exit_code == 0
+
+        # Test values and updates
+
+        res = await runner.invoke(alias, ["foo", "--child", child_device_id], obj=dev)
+        assert "Alias set to: foo" in res.output
+        assert res.exit_code == 0
+
+        # Test help has command options plus child options
+
+        res = await runner.invoke(energy, ["--help"], obj=dev)
+        assert "--year" in res.output
+        assert "--child" in res.output
+        assert "--child-index" in res.output
+        assert res.exit_code == 0
+
+        # Test child update patching calls parent and is undone on exit
+
+        parent_update_spy = mocker.spy(dev, "update")
+        res = await runner.invoke(alias, ["bar", "--child", child_device_id], obj=dev)
+        assert "Alias set to: bar" in res.output
+        assert res.exit_code == 0
+        parent_update_spy.assert_called_once()
+        assert dev.children[0].update == child_update_method
